#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ASIN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ASIN_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/asin.hpp>

#endif
